from greg.models import Identity
from ..iga import IgaPerson
from ..uib import UibSebra


UIB_USERS = {
    "Resources": [
        {
            "id": "1",
        }
    ]
}
UIB_SEARCH = {
    "schemas": [""],
    "id": 1,
    "meta": {
        "created": "2020-11-04T07:35:18Z",
        "lastModified": "2020-11-04T07:35:18Z",
        "resourceType": "User",
    },
    "username": "",
    "active": True,
    "no:edu:scim:user": {
        "accountType": "primary",
        "employeeNumber": "102160",
        "eduPersonPrincipalName": "ruped001@uib.no",
        "userPrincipalName": "Ruth.Pedersen@uibtest.no",
    },
}


def test_uib_search(requests_mock):
    """Regular search works as expected"""
    requests_mock.get(
        "http://example.com/sebra/Users?norEduPersonNIN=1",
        json=UIB_USERS,
    )
    uib_search_wname = UIB_SEARCH.copy()
    uib_search_wname["name"] = {
        "formatted": "Ruth Pedersen",
        "givenName": "Ruth",
        "familyName": "Pedersen",
    }
    requests_mock.get(
        "http://example.com/sebra/Users/1",
        json=uib_search_wname,
    )

    client = UibSebra({"url": "http://example.com/sebra/", "headers": {"bar": "baz"}})
    assert not client.extid_search(Identity.IdentityType.PASSPORT_NUMBER, 1)
    assert client.extid_search(
        Identity.IdentityType.NORWEGIAN_NATIONAL_ID_NUMBER, 1
    ) == IgaPerson(first="Ruth", last="Pedersen")


def test_uib_search_nameless(requests_mock):
    """Nameless people can be also be found"""
    requests_mock.get(
        "http://example.com/sebra/Users?norEduPersonNIN=1",
        json=UIB_USERS,
    )
    requests_mock.get(
        "http://example.com/sebra/Users/1",
        json=UIB_SEARCH,
    )

    client = UibSebra({"url": "http://example.com/sebra/", "headers": {"bar": "baz"}})
    assert not client.extid_search(Identity.IdentityType.PASSPORT_NUMBER, 1)
    assert client.extid_search(
        Identity.IdentityType.NORWEGIAN_NATIONAL_ID_NUMBER, 1
    ) == IgaPerson(first=None, last=None)
